Learn R Programming

heterometa (version 0.4)

heterometa-package: tools:::Rd_package_title("heterometa")

Description

tools:::Rd_package_description("heterometa")

Arguments

Details

tools:::Rd_package_indices("heterometa")

Published meta--analyses often only provide a subset of the heterogeneity measures first described in higgins02;textualheterometa. This package provides a way of converting between some of them. It allows for the input of I2, Q or p and outputs Q, H, I2, and confidence intervals for them. It also contains the data used as examples in that original article.

References